@@ -1,5 +1,4 @@
-from __future__ import annotations
-
+# -*- coding: utf-8 -*-
 from django.dispatch import Signal
 
 pre_transition = Signal()
