@@ -1,23 +1,19 @@
-from __future__ import annotations
-
 from django.db import models
 from django.test import TestCase
-
-from django_fsm import FSMField
-from django_fsm import transition
+from django_fsm import FSMField, transition
 
 
-class WorkflowMixin:
-    @transition(field="state", source="*", target="draft")
+class WorkflowMixin(object):
+    @transition(field='state', source="*", target='draft')
     def draft(self):
         pass
 
-    @transition(field="state", source="draft", target="published")
+    @transition(field='state', source="draft", target='published')
     def publish(self):
         pass
 
     class Meta:
-        app_label = "testapp"
+        app_label = 'testapp'
 
 
 class MixinSupportTestModel(WorkflowMixin, models.Model):
@@ -29,7 +25,7 @@ class Test(TestCase):
         model = MixinSupportTestModel()
 
         model.draft()
-        self.assertEqual(model.state, "draft")
+        self.assertEqual(model.state, 'draft')
 
         model.publish()
-        self.assertEqual(model.state, "published")
+        self.assertEqual(model.state, 'published')
